v2.0.0
======

* Require Python 3.6 or later.
* Moved release CI to Azure Pipelines.

v1.0.1
======

* Refreshed package metadata.

v1.0.0
======

* Present ``jaraco.envs`` module from adopted from
  ``jaraco.services.envs`` in jaraco.services 2.0.
